function showe(in,out,s,d)
% showe	- Displays stream and enthalpy information for energy balance
%
% function showe(in,out,s,d)
% Arguments:
%      in      the inlet stream indices.
%      out     the exit stream indices. 
%      s       the number of spaces for listing flows.
%      d       the number of decimals to display flows.
%
% Example:
%    >> showe(1:2,3,10,3)
%    will display streams 1 and 2 as inlet streams
%    and 3 as the exit stream.
%
% help revised by MAH
global ns ne
sne=size(ne);
ns=ne(:,4:sne(2));
disp(dsplaye(in,out,s,d));
